import Flutter
import UIKit

public class SwiftWatermarkShareablePlugin: NSObject, FlutterPlugin {
    var controller: UIViewController!
    var globalResult: FlutterResult!
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "watermark_shareable", binaryMessenger: registrar.messenger())
        let instance = SwiftWatermarkShareablePlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        controller = UIApplication.shared.keyWindow?.rootViewController
        globalResult = result
        switch(call.method) {
        case "getPostWithWaterMark":
            if let args = call.arguments as? String {
                result(getPostWithWaterMark(imageFile: args))
            }
            break
        default:
            break
        }
        result("iOS " + UIDevice.current.systemVersion)
    }
    
    func getPostWithWaterMark(imageFile: String) -> Data? {
        
        let image: UIImage = UIImage(contentsOfFile: imageFile)!
        let resultImg = self.drawOnImage(image: image)
        
        return resultImg
    }
    
    func drawOnImage(image: UIImage) -> Data {
        
        UIGraphicsBeginImageContext(image.size)
        
        image.draw(at: CGPoint.zero)
        
        let img2 = UIImage(named: "water_mark_free")
        
        let rect = CGRect(x: 0, y: 0, width: image.size.width, height: image.size.height)
        
        let rectSignature = CGRect(
            x: image.size.width * 0.92,
            y: UIScreen.main.bounds.size.height*0.5,
            width: image.size.width * 0.1,
            height: image.size.height * 0.8)
        
        UIGraphicsBeginImageContextWithOptions(image.size, true, 0)
        
        image.draw(in: rect, blendMode: .normal, alpha: 1)
        img2?.draw(in: rectSignature, blendMode: .normal, alpha: 1)
        
        let myImage = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        let data = myImage?.pngData()
        
        return data!
    }
    
    
}


