import UIKit

extension UIImage {
    static let waterMarkImage : UIImage? = UIImage(named:"water_mark_free")
    
    func resized(withPercentage percentage: CGFloat) -> UIImage? {
        let canvasSize = CGSize(width: size.width * percentage, height: size.height * percentage)
        UIGraphicsBeginImageContextWithOptions(canvasSize, false, scale)
        defer { UIGraphicsEndImageContext() }
        draw(in: CGRect(origin: .zero, size: canvasSize))
        return UIGraphicsGetImageFromCurrentImageContext()
    }
    func resized(toWidth width: CGFloat) -> UIImage? {
        let canvasSize = CGSize(width: width, height: CGFloat(ceil(width/size.width * size.height)))
        UIGraphicsBeginImageContextWithOptions(canvasSize, false, scale)
        defer { UIGraphicsEndImageContext() }
        draw(in: CGRect(origin: .zero, size: canvasSize))
        return UIGraphicsGetImageFromCurrentImageContext()
    }
    
    func cropping(rect:CGRect) -> UIImage? {
        guard let cgImage = self.cgImage else { return nil }
        guard let croppedImage = cgImage.cropping(to: rect) else { return nil }
        
        let newImage = UIImage(cgImage: croppedImage)
        return newImage
    }
    
    func waterMarked() -> UIImage? {
        
        let canvasSize = CGRect(x: 0, y: 0, width: size.width, height: size.height)
        guard let mark = UIImage.waterMarkImage?.cropping(rect: canvasSize) else { return nil }
        
        UIGraphicsBeginImageContextWithOptions(size, true, 0)
        guard let context = UIGraphicsGetCurrentContext() else { return nil }
        defer { UIGraphicsEndImageContext() }
        
        context.setFillColor(UIColor.white.cgColor)
        context.fill(canvasSize)
        
        self.draw(in: canvasSize, blendMode: .normal, alpha: 1)
        mark.draw(in: canvasSize, blendMode: .normal, alpha: 1)
        
        let result = UIGraphicsGetImageFromCurrentImageContext()
        
        return result
        
    }
}
